# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ParameterDocOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'default_value': 'str',
        'description': 'str',
        'name': 'str',
        'optional': 'bool',
        'type': 'str'
    }

    attribute_map = {
        'default_value': 'defaultValue',
        'description': 'description',
        'name': 'name',
        'optional': 'optional',
        'type': 'type'
    }

    def __init__(self, default_value=None, description=None, name=None, optional=False, type=None):
        """
        ParameterDocOutputV1 - a model defined in Swagger
        """

        self._default_value = None
        self._description = None
        self._name = None
        self._optional = None
        self._type = None

        if default_value is not None:
          self.default_value = default_value
        if description is not None:
          self.description = description
        if name is not None:
          self.name = name
        if optional is not None:
          self.optional = optional
        if type is not None:
          self.type = type

    @property
    def default_value(self):
        """
        Gets the default_value of this ParameterDocOutputV1.
        The value to be used if not provided to the function

        :return: The default_value of this ParameterDocOutputV1.
        :rtype: str
        """
        return self._default_value

    @default_value.setter
    def default_value(self, default_value):
        """
        Sets the default_value of this ParameterDocOutputV1.
        The value to be used if not provided to the function

        :param default_value: The default_value of this ParameterDocOutputV1.
        :type: str
        """

        self._default_value = default_value

    @property
    def description(self):
        """
        Gets the description of this ParameterDocOutputV1.
        The description of the parameter

        :return: The description of this ParameterDocOutputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ParameterDocOutputV1.
        The description of the parameter

        :param description: The description of this ParameterDocOutputV1.
        :type: str
        """

        self._description = description

    @property
    def name(self):
        """
        Gets the name of this ParameterDocOutputV1.
        The identifier of the parameter

        :return: The name of this ParameterDocOutputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ParameterDocOutputV1.
        The identifier of the parameter

        :param name: The name of this ParameterDocOutputV1.
        :type: str
        """

        self._name = name

    @property
    def optional(self):
        """
        Gets the optional of this ParameterDocOutputV1.
        Indicate this parameter is optional for the function call

        :return: The optional of this ParameterDocOutputV1.
        :rtype: bool
        """
        return self._optional

    @optional.setter
    def optional(self, optional):
        """
        Sets the optional of this ParameterDocOutputV1.
        Indicate this parameter is optional for the function call

        :param optional: The optional of this ParameterDocOutputV1.
        :type: bool
        """

        self._optional = optional

    @property
    def type(self):
        """
        Gets the type of this ParameterDocOutputV1.
        The type of the parameter

        :return: The type of this ParameterDocOutputV1.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this ParameterDocOutputV1.
        The type of the parameter

        :param type: The type of this ParameterDocOutputV1.
        :type: str
        """

        self._type = type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ParameterDocOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class RehydrationInstructionsOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'lookup': 'list[RehydrationSeriesLookupOutputV1]',
        'map_marker': 'MapMarkerRehydrationInstructionsOutputV1',
        'radial': 'RadialRehydrationInstructionsOutputV1',
        'radial_gauge': 'RadialGaugeRehydrationInstructionsOutputV1',
        'series_identifier': 'str'
    }

    attribute_map = {
        'lookup': 'lookup',
        'map_marker': 'mapMarker',
        'radial': 'radial',
        'radial_gauge': 'radialGauge',
        'series_identifier': 'seriesIdentifier'
    }

    def __init__(self, lookup=None, map_marker=None, radial=None, radial_gauge=None, series_identifier=None):
        """
        RehydrationInstructionsOutputV1 - a model defined in Swagger
        """

        self._lookup = None
        self._map_marker = None
        self._radial = None
        self._radial_gauge = None
        self._series_identifier = None

        if lookup is not None:
          self.lookup = lookup
        if map_marker is not None:
          self.map_marker = map_marker
        if radial is not None:
          self.radial = radial
        if radial_gauge is not None:
          self.radial_gauge = radial_gauge
        if series_identifier is not None:
          self.series_identifier = series_identifier

    @property
    def lookup(self):
        """
        Gets the lookup of this RehydrationInstructionsOutputV1.
        Lookup mapping between chart series display names and data series identifiers

        :return: The lookup of this RehydrationInstructionsOutputV1.
        :rtype: list[RehydrationSeriesLookupOutputV1]
        """
        return self._lookup

    @lookup.setter
    def lookup(self, lookup):
        """
        Sets the lookup of this RehydrationInstructionsOutputV1.
        Lookup mapping between chart series display names and data series identifiers

        :param lookup: The lookup of this RehydrationInstructionsOutputV1.
        :type: list[RehydrationSeriesLookupOutputV1]
        """

        self._lookup = lookup

    @property
    def map_marker(self):
        """
        Gets the map_marker of this RehydrationInstructionsOutputV1.

        :return: The map_marker of this RehydrationInstructionsOutputV1.
        :rtype: MapMarkerRehydrationInstructionsOutputV1
        """
        return self._map_marker

    @map_marker.setter
    def map_marker(self, map_marker):
        """
        Sets the map_marker of this RehydrationInstructionsOutputV1.

        :param map_marker: The map_marker of this RehydrationInstructionsOutputV1.
        :type: MapMarkerRehydrationInstructionsOutputV1
        """

        self._map_marker = map_marker

    @property
    def radial(self):
        """
        Gets the radial of this RehydrationInstructionsOutputV1.

        :return: The radial of this RehydrationInstructionsOutputV1.
        :rtype: RadialRehydrationInstructionsOutputV1
        """
        return self._radial

    @radial.setter
    def radial(self, radial):
        """
        Sets the radial of this RehydrationInstructionsOutputV1.

        :param radial: The radial of this RehydrationInstructionsOutputV1.
        :type: RadialRehydrationInstructionsOutputV1
        """

        self._radial = radial

    @property
    def radial_gauge(self):
        """
        Gets the radial_gauge of this RehydrationInstructionsOutputV1.

        :return: The radial_gauge of this RehydrationInstructionsOutputV1.
        :rtype: RadialGaugeRehydrationInstructionsOutputV1
        """
        return self._radial_gauge

    @radial_gauge.setter
    def radial_gauge(self, radial_gauge):
        """
        Sets the radial_gauge of this RehydrationInstructionsOutputV1.

        :param radial_gauge: The radial_gauge of this RehydrationInstructionsOutputV1.
        :type: RadialGaugeRehydrationInstructionsOutputV1
        """

        self._radial_gauge = radial_gauge

    @property
    def series_identifier(self):
        """
        Gets the series_identifier of this RehydrationInstructionsOutputV1.
        Identifier that maps series data to chart options

        :return: The series_identifier of this RehydrationInstructionsOutputV1.
        :rtype: str
        """
        return self._series_identifier

    @series_identifier.setter
    def series_identifier(self, series_identifier):
        """
        Sets the series_identifier of this RehydrationInstructionsOutputV1.
        Identifier that maps series data to chart options

        :param series_identifier: The series_identifier of this RehydrationInstructionsOutputV1.
        :type: str
        """

        self._series_identifier = series_identifier

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, RehydrationInstructionsOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class TableDefinitionCSVPublishRowsOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'row_created_or_updated_count': 'int',
        'row_error_count': 'int'
    }

    attribute_map = {
        'row_created_or_updated_count': 'rowCreatedOrUpdatedCount',
        'row_error_count': 'rowErrorCount'
    }

    def __init__(self, row_created_or_updated_count=None, row_error_count=None):
        """
        TableDefinitionCSVPublishRowsOutputV1 - a model defined in Swagger
        """

        self._row_created_or_updated_count = None
        self._row_error_count = None

        if row_created_or_updated_count is not None:
          self.row_created_or_updated_count = row_created_or_updated_count
        if row_error_count is not None:
          self.row_error_count = row_error_count

    @property
    def row_created_or_updated_count(self):
        """
        Gets the row_created_or_updated_count of this TableDefinitionCSVPublishRowsOutputV1.
        The number of rows created successfully

        :return: The row_created_or_updated_count of this TableDefinitionCSVPublishRowsOutputV1.
        :rtype: int
        """
        return self._row_created_or_updated_count

    @row_created_or_updated_count.setter
    def row_created_or_updated_count(self, row_created_or_updated_count):
        """
        Sets the row_created_or_updated_count of this TableDefinitionCSVPublishRowsOutputV1.
        The number of rows created successfully

        :param row_created_or_updated_count: The row_created_or_updated_count of this TableDefinitionCSVPublishRowsOutputV1.
        :type: int
        """
        if row_created_or_updated_count is None:
            raise ValueError("Invalid value for `row_created_or_updated_count`, must not be `None`")

        self._row_created_or_updated_count = row_created_or_updated_count

    @property
    def row_error_count(self):
        """
        Gets the row_error_count of this TableDefinitionCSVPublishRowsOutputV1.
        The number of rows that could not be created due to errors

        :return: The row_error_count of this TableDefinitionCSVPublishRowsOutputV1.
        :rtype: int
        """
        return self._row_error_count

    @row_error_count.setter
    def row_error_count(self, row_error_count):
        """
        Sets the row_error_count of this TableDefinitionCSVPublishRowsOutputV1.
        The number of rows that could not be created due to errors

        :param row_error_count: The row_error_count of this TableDefinitionCSVPublishRowsOutputV1.
        :type: int
        """
        if row_error_count is None:
            raise ValueError("Invalid value for `row_error_count`, must not be `None`")

        self._row_error_count = row_error_count

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TableDefinitionCSVPublishRowsOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

__version__ = "66.106.1"

# import apis into sdk package
from .access_keys_api import AccessKeysApi
from .add_ons_api import AddOnsApi
from .agents_api import AgentsApi
from .annotations_api import AnnotationsApi
from .applications_api import ApplicationsApi
from .assets_api import AssetsApi
from .audit_api import AuditApi
from .auth_api import AuthApi
from .boards_api import BoardsApi
from .cache_api import CacheApi
from .calculated_tables_api import CalculatedTablesApi
from .condition_monitors_api import ConditionMonitorsApi
from .conditions_api import ConditionsApi
from .content_api import ContentApi
from .context_api import ContextApi
from .datafiles_api import DatafilesApi
from .datasources_api import DatasourcesApi
from .display_templates_api import DisplayTemplatesApi
from .displays_api import DisplaysApi
from .export_api import ExportApi
from .folders_api import FoldersApi
from .formulas_api import FormulasApi
from .graph_ql_api import GraphQLApi
from .hierarchies_api import HierarchiesApi
from .items_api import ItemsApi
from .jobs_api import JobsApi
from .logs_api import LogsApi
from .markdown_items_api import MarkdownItemsApi
from .markdown_links_api import MarkdownLinksApi
from .materialized_tables_api import MaterializedTablesApi
from .metrics_api import MetricsApi
from .models_api import ModelsApi
from .monitors_api import MonitorsApi
from .networks_api import NetworksApi
from .notification_configurations_api import NotificationConfigurationsApi
from .notifier_api import NotifierApi
from .plugins_api import PluginsApi
from .projects_api import ProjectsApi
from .report_templates_api import ReportTemplatesApi
from .reports_api import ReportsApi
from .requests_api import RequestsApi
from .scim_api import SCIMApi
from .scalars_api import ScalarsApi
from .sharing_api import SharingApi
from .signal_monitors_api import SignalMonitorsApi
from .signals_api import SignalsApi
from .stored_tables_api import StoredTablesApi
from .subscriptions_api import SubscriptionsApi
from .system_api import SystemApi
from .table_definitions_api import TableDefinitionsApi
from .tables_api import TablesApi
from .trees_api import TreesApi
from .usage_api import UsageApi
from .user_groups_api import UserGroupsApi
from .users_api import UsersApi
from .workbooks_api import WorkbooksApi



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import sys
import os
import re

from deprecated import deprecated
# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient
from ..models import *

class ConditionMonitorsApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def archive_condition_monitor(self, **kwargs):
        """
        Archive a condition monitor
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.archive_condition_monitor(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: ID of the condition monitor to archive. (required)
        :return: ArchiveOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ArchiveOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.archive_condition_monitor_with_http_info(**kwargs)
        else:
            (data) = self.archive_condition_monitor_with_http_info(**kwargs)
            return data

    def archive_condition_monitor_with_http_info(self, **kwargs):
        """
        Archive a condition monitor
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.archive_condition_monitor_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: ID of the condition monitor to archive. (required)
        :return: ArchiveOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ArchiveOutputV1
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method archive_condition_monitor" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `archive_condition_monitor`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/condition-monitors/{id}', 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'ArchiveOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def create_condition_monitor(self, **kwargs):
        """
        Create a new condition monitor
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_condition_monitor(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ConditionMonitorInputV1 body: (required)
        :return: ConditionMonitorOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ConditionMonitorOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.create_condition_monitor_with_http_info(**kwargs)
        else:
            (data) = self.create_condition_monitor_with_http_info(**kwargs)
            return data

    def create_condition_monitor_with_http_info(self, **kwargs):
        """
        Create a new condition monitor
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_condition_monitor_with_http_info(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ConditionMonitorInputV1 body: (required)
        :return: ConditionMonitorOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ConditionMonitorOutputV1
        """

        all_params = ['body']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_condition_monitor" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_condition_monitor`")


        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/condition-monitors', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'ConditionMonitorOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_condition_monitor(self, **kwargs):
        """
        Get a condition monitor
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_condition_monitor(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The Seeq ID for the condition monitor (required)
        :return: ConditionMonitorOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ConditionMonitorOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_condition_monitor_with_http_info(**kwargs)
        else:
            (data) = self.get_condition_monitor_with_http_info(**kwargs)
            return data

    def get_condition_monitor_with_http_info(self, **kwargs):
        """
        Get a condition monitor
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_condition_monitor_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The Seeq ID for the condition monitor (required)
        :return: ConditionMonitorOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ConditionMonitorOutputV1
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_condition_monitor" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_condition_monitor`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/condition-monitors/{id}', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'ConditionMonitorOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_condition_monitor_metadata_list(self, **kwargs):
        """
        Get a list of metadata associated with condition monitors, including various properties that define their current state and behavior
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_condition_monitor_metadata_list(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[str] creator_ids: Filter items to only those created by the specified user IDs
        :param str name_search: Filter the items to those whose name match any part of the specified string
        :param str workbook_search: Filter the items to those whose condition are scoped to workbooks that match any part of the specified string
        :param list[str] condition_ids: Filter items to only those that are monitoring one of the specified conditions as specified by the list of IDs
        :param bool enabled_filter: Filter items by their enabled status
        :param str workbook_type_filter: Filter items by the type of workbook they are scoped to
        :param int offset: The pagination offset, the number of items that will be skipped.
        :param int limit: The pagination limit, the total number of items that will be returned in this page of results
        :param str sort_by: Order the items by either name, workbook or createdAt
        :param bool sort_asc: Sorts the sort field in ascending order when true and descending when false
        :return: ConditionMonitorMetadataOutputListV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ConditionMonitorMetadataOutputListV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_condition_monitor_metadata_list_with_http_info(**kwargs)
        else:
            (data) = self.get_condition_monitor_metadata_list_with_http_info(**kwargs)
            return data

    def get_condition_monitor_metadata_list_with_http_info(self, **kwargs):
        """
        Get a list of metadata associated with condition monitors, including various properties that define their current state and behavior
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_condition_monitor_metadata_list_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[str] creator_ids: Filter items to only those created by the specified user IDs
        :param str name_search: Filter the items to those whose name match any part of the specified string
        :param str workbook_search: Filter the items to those whose condition are scoped to workbooks that match any part of the specified string
        :param list[str] condition_ids: Filter items to only those that are monitoring one of the specified conditions as specified by the list of IDs
        :param bool enabled_filter: Filter items by their enabled status
        :param str workbook_type_filter: Filter items by the type of workbook they are scoped to
        :param int offset: The pagination offset, the number of items that will be skipped.
        :param int limit: The pagination limit, the total number of items that will be returned in this page of results
        :param str sort_by: Order the items by either name, workbook or createdAt
        :param bool sort_asc: Sorts the sort field in ascending order when true and descending when false
        :return: ConditionMonitorMetadataOutputListV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ConditionMonitorMetadataOutputListV1
        """

        all_params = ['creator_ids', 'name_search', 'workbook_search', 'condition_ids', 'enabled_filter', 'workbook_type_filter', 'offset', 'limit', 'sort_by', 'sort_asc']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_condition_monitor_metadata_list" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'creator_ids' in params:
            query_params.append(('creatorIds', params['creator_ids']))
            collection_formats['creatorIds'] = 'multi'
        if 'name_search' in params:
            query_params.append(('nameSearch', params['name_search']))
        if 'workbook_search' in params:
            query_params.append(('workbookSearch', params['workbook_search']))
        if 'condition_ids' in params:
            query_params.append(('conditionIds', params['condition_ids']))
            collection_formats['conditionIds'] = 'multi'
        if 'enabled_filter' in params:
            query_params.append(('enabledFilter', params['enabled_filter']))
        if 'workbook_type_filter' in params:
            query_params.append(('workbookTypeFilter', params['workbook_type_filter']))
        if 'offset' in params:
            query_params.append(('offset', params['offset']))
        if 'limit' in params:
            query_params.append(('limit', params['limit']))
        if 'sort_by' in params:
            query_params.append(('sortBy', params['sort_by']))
        if 'sort_asc' in params:
            query_params.append(('sortAsc', params['sort_asc']))

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/condition-monitors/metadata', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'ConditionMonitorMetadataOutputListV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_condition_monitor_suppressions(self, **kwargs):
        """
        Get suppressed conditions for a condition monitor
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_condition_monitor_suppressions(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The Seeq ID for the condition monitor (required)
        :return: list[SuppressedConditionOutputV1]
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: list[SuppressedConditionOutputV1]
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_condition_monitor_suppressions_with_http_info(**kwargs)
        else:
            (data) = self.get_condition_monitor_suppressions_with_http_info(**kwargs)
            return data

    def get_condition_monitor_suppressions_with_http_info(self, **kwargs):
        """
        Get suppressed conditions for a condition monitor
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_condition_monitor_suppressions_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The Seeq ID for the condition monitor (required)
        :return: list[SuppressedConditionOutputV1]
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: list[SuppressedConditionOutputV1]
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_condition_monitor_suppressions" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_condition_monitor_suppressions`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/condition-monitors/{id}/suppressions', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'list[SuppressedConditionOutputV1]'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_condition_monitors(self, **kwargs):
        """
        Get a list of condition monitors
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_condition_monitors(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[str] executor_ids: Filter condition monitors to only those created by the specified user IDs
        :param str name_search: Filter the condition monitors to those whose name match any part of the specified string
        :param list[str] condition_ids: Filter condition monitors to only those that are monitoring one of the specified conditions as specified by the list of IDs
        :param bool enabled_filter: Filter condition monitors by their enabled status
        :param int offset: Whether to filter condition monitors to only users who are enabled.
        :param int limit: The pagination limit, the total number of condition monitor that will be returned in this page of results
        :param str sort_field: Orders the condition monitors by either name, createdAt or workbook
        :param bool sort_asc: Sorts the sort field in ascending order when true and descending when false
        :return: GetConditionMonitorItemsOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: GetConditionMonitorItemsOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_condition_monitors_with_http_info(**kwargs)
        else:
            (data) = self.get_condition_monitors_with_http_info(**kwargs)
            return data

    def get_condition_monitors_with_http_info(self, **kwargs):
        """
        Get a list of condition monitors
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_condition_monitors_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[str] executor_ids: Filter condition monitors to only those created by the specified user IDs
        :param str name_search: Filter the condition monitors to those whose name match any part of the specified string
        :param list[str] condition_ids: Filter condition monitors to only those that are monitoring one of the specified conditions as specified by the list of IDs
        :param bool enabled_filter: Filter condition monitors by their enabled status
        :param int offset: Whether to filter condition monitors to only users who are enabled.
        :param int limit: The pagination limit, the total number of condition monitor that will be returned in this page of results
        :param str sort_field: Orders the condition monitors by either name, createdAt or workbook
        :param bool sort_asc: Sorts the sort field in ascending order when true and descending when false
        :return: GetConditionMonitorItemsOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: GetConditionMonitorItemsOutputV1
        """

        all_params = ['executor_ids', 'name_search', 'condition_ids', 'enabled_filter', 'offset', 'limit', 'sort_field', 'sort_asc']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_condition_monitors" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'executor_ids' in params:
            query_params.append(('executorIds', params['executor_ids']))
            collection_formats['executorIds'] = 'multi'
        if 'name_search' in params:
            query_params.append(('nameSearch', params['name_search']))
        if 'condition_ids' in params:
            query_params.append(('conditionIds', params['condition_ids']))
            collection_formats['conditionIds'] = 'multi'
        if 'enabled_filter' in params:
            query_params.append(('enabledFilter', params['enabled_filter']))
        if 'offset' in params:
            query_params.append(('offset', params['offset']))
        if 'limit' in params:
            query_params.append(('limit', params['limit']))
        if 'sort_field' in params:
            query_params.append(('sortField', params['sort_field']))
        if 'sort_asc' in params:
            query_params.append(('sortAsc', params['sort_asc']))

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/condition-monitors', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'GetConditionMonitorItemsOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_monitored_conditions(self, **kwargs):
        """
        Get a list of monitored conditions for a condition monitor
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_monitored_conditions(condition_monitor_id=condition_monitor_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str condition_monitor_id: (required)
        :return: MonitoredConditionOutputListV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: MonitoredConditionOutputListV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_monitored_conditions_with_http_info(**kwargs)
        else:
            (data) = self.get_monitored_conditions_with_http_info(**kwargs)
            return data

    def get_monitored_conditions_with_http_info(self, **kwargs):
        """
        Get a list of monitored conditions for a condition monitor
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_monitored_conditions_with_http_info(condition_monitor_id=condition_monitor_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str condition_monitor_id: (required)
        :return: MonitoredConditionOutputListV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: MonitoredConditionOutputListV1
        """

        all_params = ['condition_monitor_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_monitored_conditions" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'condition_monitor_id' is set
        if ('condition_monitor_id' not in params) or (params['condition_monitor_id'] is None):
            raise ValueError("Missing the required parameter `condition_monitor_id` when calling `get_monitored_conditions`")


        collection_formats = {}

        path_params = {}
        if 'condition_monitor_id' in params:
            path_params['conditionMonitorId'] = params['condition_monitor_id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/condition-monitors/{conditionMonitorId}/conditions', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'MonitoredConditionOutputListV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def run_condition_monitor_job(self, **kwargs):
        """
        Triggers an immediate execution of the condition monitor job if it is not currently running. If the job is already, run after current job completes.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.run_condition_monitor_job(body=body_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param RunConditionMonitorJobInputV1 body: (required)
        :param str id: The Seeq ID for the condition monitor (required)
        :return: StatusMessageBase
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: StatusMessageBase
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.run_condition_monitor_job_with_http_info(**kwargs)
        else:
            (data) = self.run_condition_monitor_job_with_http_info(**kwargs)
            return data

    def run_condition_monitor_job_with_http_info(self, **kwargs):
        """
        Triggers an immediate execution of the condition monitor job if it is not currently running. If the job is already, run after current job completes.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.run_condition_monitor_job_with_http_info(body=body_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param RunConditionMonitorJobInputV1 body: (required)
        :param str id: The Seeq ID for the condition monitor (required)
        :return: StatusMessageBase
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: StatusMessageBase
        """

        all_params = ['body', 'id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method run_condition_monitor_job" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `run_condition_monitor_job`")
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `run_condition_monitor_job`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/condition-monitors/{id}/run', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'StatusMessageBase'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def suppress_conditions(self, **kwargs):
        """
        Suppress one or more conditions in a condition monitor
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.suppress_conditions(body=body_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[SuppressConditionInputV1] body: (required)
        :param str id: The Seeq ID for the condition monitor (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.suppress_conditions_with_http_info(**kwargs)
        else:
            (data) = self.suppress_conditions_with_http_info(**kwargs)
            return data

    def suppress_conditions_with_http_info(self, **kwargs):
        """
        Suppress one or more conditions in a condition monitor
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.suppress_conditions_with_http_info(body=body_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[SuppressConditionInputV1] body: (required)
        :param str id: The Seeq ID for the condition monitor (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        all_params = ['body', 'id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method suppress_conditions" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `suppress_conditions`")
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `suppress_conditions`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/condition-monitors/{id}/suppress', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', None),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def unsuppress_conditions(self, **kwargs):
        """
        Unsuppress one or more conditions in a condition monitor
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.unsuppress_conditions(body=body_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[str] body: Array of condition IDs to unsuppress (required)
        :param str id: The Seeq ID for the condition monitor (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.unsuppress_conditions_with_http_info(**kwargs)
        else:
            (data) = self.unsuppress_conditions_with_http_info(**kwargs)
            return data

    def unsuppress_conditions_with_http_info(self, **kwargs):
        """
        Unsuppress one or more conditions in a condition monitor
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.unsuppress_conditions_with_http_info(body=body_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[str] body: Array of condition IDs to unsuppress (required)
        :param str id: The Seeq ID for the condition monitor (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        all_params = ['body', 'id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method unsuppress_conditions" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `unsuppress_conditions`")
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `unsuppress_conditions`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/condition-monitors/{id}/unsuppress', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', None),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def update_condition_monitor(self, **kwargs):
        """
        Update a condition monitor
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_condition_monitor(body=body_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ConditionMonitorInputV1 body: (required)
        :param str id: The Seeq ID for the condition monitor (required)
        :return: ConditionMonitorOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ConditionMonitorOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.update_condition_monitor_with_http_info(**kwargs)
        else:
            (data) = self.update_condition_monitor_with_http_info(**kwargs)
            return data

    def update_condition_monitor_with_http_info(self, **kwargs):
        """
        Update a condition monitor
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_condition_monitor_with_http_info(body=body_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ConditionMonitorInputV1 body: (required)
        :param str id: The Seeq ID for the condition monitor (required)
        :return: ConditionMonitorOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ConditionMonitorOutputV1
        """

        all_params = ['body', 'id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_condition_monitor" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_condition_monitor`")
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `update_condition_monitor`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/condition-monitors/{id}', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'ConditionMonitorOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class GroupBy(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'group_keys': 'list[object]',
        'row_group_column_ids': 'list[str]',
        'value_columns': 'list[GroupValueColumn]'
    }

    attribute_map = {
        'group_keys': 'groupKeys',
        'row_group_column_ids': 'rowGroupColumnIds',
        'value_columns': 'valueColumns'
    }

    def __init__(self, group_keys=None, row_group_column_ids=None, value_columns=None):
        """
        GroupBy - a model defined in Swagger
        """

        self._group_keys = None
        self._row_group_column_ids = None
        self._value_columns = None

        if group_keys is not None:
          self.group_keys = group_keys
        if row_group_column_ids is not None:
          self.row_group_column_ids = row_group_column_ids
        if value_columns is not None:
          self.value_columns = value_columns

    @property
    def group_keys(self):
        """
        Gets the group_keys of this GroupBy.
        Expanded group nodes

        :return: The group_keys of this GroupBy.
        :rtype: list[object]
        """
        return self._group_keys

    @group_keys.setter
    def group_keys(self, group_keys):
        """
        Sets the group_keys of this GroupBy.
        Expanded group nodes

        :param group_keys: The group_keys of this GroupBy.
        :type: list[object]
        """

        self._group_keys = group_keys

    @property
    def row_group_column_ids(self):
        """
        Gets the row_group_column_ids of this GroupBy.
        Columns to group by

        :return: The row_group_column_ids of this GroupBy.
        :rtype: list[str]
        """
        return self._row_group_column_ids

    @row_group_column_ids.setter
    def row_group_column_ids(self, row_group_column_ids):
        """
        Sets the row_group_column_ids of this GroupBy.
        Columns to group by

        :param row_group_column_ids: The row_group_column_ids of this GroupBy.
        :type: list[str]
        """

        self._row_group_column_ids = row_group_column_ids

    @property
    def value_columns(self):
        """
        Gets the value_columns of this GroupBy.
        Columns to aggregate on

        :return: The value_columns of this GroupBy.
        :rtype: list[GroupValueColumn]
        """
        return self._value_columns

    @value_columns.setter
    def value_columns(self, value_columns):
        """
        Sets the value_columns of this GroupBy.
        Columns to aggregate on

        :param value_columns: The value_columns of this GroupBy.
        :type: list[GroupValueColumn]
        """

        self._value_columns = value_columns

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, GroupBy):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class Filter(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'composite_filter': 'CompositeFilter',
        'simple_filter': 'SimpleFilter',
        'value_filter': 'ValueFilter'
    }

    attribute_map = {
        'composite_filter': 'compositeFilter',
        'simple_filter': 'simpleFilter',
        'value_filter': 'valueFilter'
    }

    def __init__(self, composite_filter=None, simple_filter=None, value_filter=None):
        """
        Filter - a model defined in Swagger
        """

        self._composite_filter = None
        self._simple_filter = None
        self._value_filter = None

        if composite_filter is not None:
          self.composite_filter = composite_filter
        if simple_filter is not None:
          self.simple_filter = simple_filter
        if value_filter is not None:
          self.value_filter = value_filter

    @property
    def composite_filter(self):
        """
        Gets the composite_filter of this Filter.

        :return: The composite_filter of this Filter.
        :rtype: CompositeFilter
        """
        return self._composite_filter

    @composite_filter.setter
    def composite_filter(self, composite_filter):
        """
        Sets the composite_filter of this Filter.

        :param composite_filter: The composite_filter of this Filter.
        :type: CompositeFilter
        """

        self._composite_filter = composite_filter

    @property
    def simple_filter(self):
        """
        Gets the simple_filter of this Filter.

        :return: The simple_filter of this Filter.
        :rtype: SimpleFilter
        """
        return self._simple_filter

    @simple_filter.setter
    def simple_filter(self, simple_filter):
        """
        Sets the simple_filter of this Filter.

        :param simple_filter: The simple_filter of this Filter.
        :type: SimpleFilter
        """

        self._simple_filter = simple_filter

    @property
    def value_filter(self):
        """
        Gets the value_filter of this Filter.

        :return: The value_filter of this Filter.
        :rtype: ValueFilter
        """
        return self._value_filter

    @value_filter.setter
    def value_filter(self, value_filter):
        """
        Sets the value_filter of this Filter.

        :param value_filter: The value_filter of this Filter.
        :type: ValueFilter
        """

        self._value_filter = value_filter

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Filter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class TileUpdateInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'background_color': 'str',
        'border_color': 'str',
        'chart_options': 'str',
        'data_view_id': 'str',
        'decimal_places': 'int',
        'grouped_by_key': 'str',
        'height': 'int',
        'name': 'str',
        'prompt': 'str',
        'rehydration_instructions': 'RehydrationInstructionsInputV1',
        'type': 'str',
        'unit': 'str',
        'value_column': 'str',
        'width': 'int',
        'worksheet_id': 'str',
        'x': 'int',
        'y': 'int'
    }

    attribute_map = {
        'background_color': 'backgroundColor',
        'border_color': 'borderColor',
        'chart_options': 'chartOptions',
        'data_view_id': 'dataViewId',
        'decimal_places': 'decimalPlaces',
        'grouped_by_key': 'groupedByKey',
        'height': 'height',
        'name': 'name',
        'prompt': 'prompt',
        'rehydration_instructions': 'rehydrationInstructions',
        'type': 'type',
        'unit': 'unit',
        'value_column': 'valueColumn',
        'width': 'width',
        'worksheet_id': 'worksheetId',
        'x': 'x',
        'y': 'y'
    }

    def __init__(self, background_color=None, border_color=None, chart_options=None, data_view_id=None, decimal_places=None, grouped_by_key=None, height=None, name=None, prompt=None, rehydration_instructions=None, type=None, unit=None, value_column=None, width=None, worksheet_id=None, x=None, y=None):
        """
        TileUpdateInputV1 - a model defined in Swagger
        """

        self._background_color = None
        self._border_color = None
        self._chart_options = None
        self._data_view_id = None
        self._decimal_places = None
        self._grouped_by_key = None
        self._height = None
        self._name = None
        self._prompt = None
        self._rehydration_instructions = None
        self._type = None
        self._unit = None
        self._value_column = None
        self._width = None
        self._worksheet_id = None
        self._x = None
        self._y = None

        if background_color is not None:
          self.background_color = background_color
        if border_color is not None:
          self.border_color = border_color
        if chart_options is not None:
          self.chart_options = chart_options
        if data_view_id is not None:
          self.data_view_id = data_view_id
        if decimal_places is not None:
          self.decimal_places = decimal_places
        if grouped_by_key is not None:
          self.grouped_by_key = grouped_by_key
        if height is not None:
          self.height = height
        if name is not None:
          self.name = name
        if prompt is not None:
          self.prompt = prompt
        if rehydration_instructions is not None:
          self.rehydration_instructions = rehydration_instructions
        if type is not None:
          self.type = type
        if unit is not None:
          self.unit = unit
        if value_column is not None:
          self.value_column = value_column
        if width is not None:
          self.width = width
        if worksheet_id is not None:
          self.worksheet_id = worksheet_id
        if x is not None:
          self.x = x
        if y is not None:
          self.y = y

    @property
    def background_color(self):
        """
        Gets the background_color of this TileUpdateInputV1.
        The background color of the tile (CSS color value)

        :return: The background_color of this TileUpdateInputV1.
        :rtype: str
        """
        return self._background_color

    @background_color.setter
    def background_color(self, background_color):
        """
        Sets the background_color of this TileUpdateInputV1.
        The background color of the tile (CSS color value)

        :param background_color: The background_color of this TileUpdateInputV1.
        :type: str
        """

        self._background_color = background_color

    @property
    def border_color(self):
        """
        Gets the border_color of this TileUpdateInputV1.
        The border color of the tile (CSS color value)

        :return: The border_color of this TileUpdateInputV1.
        :rtype: str
        """
        return self._border_color

    @border_color.setter
    def border_color(self, border_color):
        """
        Sets the border_color of this TileUpdateInputV1.
        The border color of the tile (CSS color value)

        :param border_color: The border_color of this TileUpdateInputV1.
        :type: str
        """

        self._border_color = border_color

    @property
    def chart_options(self):
        """
        Gets the chart_options of this TileUpdateInputV1.
        Chart options as JSON (for chart tiles)

        :return: The chart_options of this TileUpdateInputV1.
        :rtype: str
        """
        return self._chart_options

    @chart_options.setter
    def chart_options(self, chart_options):
        """
        Sets the chart_options of this TileUpdateInputV1.
        Chart options as JSON (for chart tiles)

        :param chart_options: The chart_options of this TileUpdateInputV1.
        :type: str
        """

        self._chart_options = chart_options

    @property
    def data_view_id(self):
        """
        Gets the data_view_id of this TileUpdateInputV1.
        Data view ID (for chart tiles)

        :return: The data_view_id of this TileUpdateInputV1.
        :rtype: str
        """
        return self._data_view_id

    @data_view_id.setter
    def data_view_id(self, data_view_id):
        """
        Sets the data_view_id of this TileUpdateInputV1.
        Data view ID (for chart tiles)

        :param data_view_id: The data_view_id of this TileUpdateInputV1.
        :type: str
        """

        self._data_view_id = data_view_id

    @property
    def decimal_places(self):
        """
        Gets the decimal_places of this TileUpdateInputV1.
        Number of decimal places to display (for KPI tiles)

        :return: The decimal_places of this TileUpdateInputV1.
        :rtype: int
        """
        return self._decimal_places

    @decimal_places.setter
    def decimal_places(self, decimal_places):
        """
        Sets the decimal_places of this TileUpdateInputV1.
        Number of decimal places to display (for KPI tiles)

        :param decimal_places: The decimal_places of this TileUpdateInputV1.
        :type: int
        """

        self._decimal_places = decimal_places

    @property
    def grouped_by_key(self):
        """
        Gets the grouped_by_key of this TileUpdateInputV1.
        Grouped by key (for chart tiles)

        :return: The grouped_by_key of this TileUpdateInputV1.
        :rtype: str
        """
        return self._grouped_by_key

    @grouped_by_key.setter
    def grouped_by_key(self, grouped_by_key):
        """
        Sets the grouped_by_key of this TileUpdateInputV1.
        Grouped by key (for chart tiles)

        :param grouped_by_key: The grouped_by_key of this TileUpdateInputV1.
        :type: str
        """

        self._grouped_by_key = grouped_by_key

    @property
    def height(self):
        """
        Gets the height of this TileUpdateInputV1.
        The height of the tile in grid units

        :return: The height of this TileUpdateInputV1.
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """
        Sets the height of this TileUpdateInputV1.
        The height of the tile in grid units

        :param height: The height of this TileUpdateInputV1.
        :type: int
        """

        self._height = height

    @property
    def name(self):
        """
        Gets the name of this TileUpdateInputV1.
        The name of the tile

        :return: The name of this TileUpdateInputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this TileUpdateInputV1.
        The name of the tile

        :param name: The name of this TileUpdateInputV1.
        :type: str
        """

        self._name = name

    @property
    def prompt(self):
        """
        Gets the prompt of this TileUpdateInputV1.
        Prompt used to generate the chart (for chart tiles created via AI)

        :return: The prompt of this TileUpdateInputV1.
        :rtype: str
        """
        return self._prompt

    @prompt.setter
    def prompt(self, prompt):
        """
        Sets the prompt of this TileUpdateInputV1.
        Prompt used to generate the chart (for chart tiles created via AI)

        :param prompt: The prompt of this TileUpdateInputV1.
        :type: str
        """

        self._prompt = prompt

    @property
    def rehydration_instructions(self):
        """
        Gets the rehydration_instructions of this TileUpdateInputV1.

        :return: The rehydration_instructions of this TileUpdateInputV1.
        :rtype: RehydrationInstructionsInputV1
        """
        return self._rehydration_instructions

    @rehydration_instructions.setter
    def rehydration_instructions(self, rehydration_instructions):
        """
        Sets the rehydration_instructions of this TileUpdateInputV1.

        :param rehydration_instructions: The rehydration_instructions of this TileUpdateInputV1.
        :type: RehydrationInstructionsInputV1
        """

        self._rehydration_instructions = rehydration_instructions

    @property
    def type(self):
        """
        Gets the type of this TileUpdateInputV1.
        The type of tile (Worksheet, Chart, CKEditor, Filter, KPI, Table)

        :return: The type of this TileUpdateInputV1.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this TileUpdateInputV1.
        The type of tile (Worksheet, Chart, CKEditor, Filter, KPI, Table)

        :param type: The type of this TileUpdateInputV1.
        :type: str
        """

        self._type = type

    @property
    def unit(self):
        """
        Gets the unit of this TileUpdateInputV1.
        The unit to display with the value (for KPI tiles)

        :return: The unit of this TileUpdateInputV1.
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """
        Sets the unit of this TileUpdateInputV1.
        The unit to display with the value (for KPI tiles)

        :param unit: The unit of this TileUpdateInputV1.
        :type: str
        """

        self._unit = unit

    @property
    def value_column(self):
        """
        Gets the value_column of this TileUpdateInputV1.
        The column name containing the value to display (for KPI tiles)

        :return: The value_column of this TileUpdateInputV1.
        :rtype: str
        """
        return self._value_column

    @value_column.setter
    def value_column(self, value_column):
        """
        Sets the value_column of this TileUpdateInputV1.
        The column name containing the value to display (for KPI tiles)

        :param value_column: The value_column of this TileUpdateInputV1.
        :type: str
        """

        self._value_column = value_column

    @property
    def width(self):
        """
        Gets the width of this TileUpdateInputV1.
        The width of the tile in grid units

        :return: The width of this TileUpdateInputV1.
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        """
        Sets the width of this TileUpdateInputV1.
        The width of the tile in grid units

        :param width: The width of this TileUpdateInputV1.
        :type: int
        """

        self._width = width

    @property
    def worksheet_id(self):
        """
        Gets the worksheet_id of this TileUpdateInputV1.
        The ID of the worksheet (for worksheet tiles)

        :return: The worksheet_id of this TileUpdateInputV1.
        :rtype: str
        """
        return self._worksheet_id

    @worksheet_id.setter
    def worksheet_id(self, worksheet_id):
        """
        Sets the worksheet_id of this TileUpdateInputV1.
        The ID of the worksheet (for worksheet tiles)

        :param worksheet_id: The worksheet_id of this TileUpdateInputV1.
        :type: str
        """

        self._worksheet_id = worksheet_id

    @property
    def x(self):
        """
        Gets the x of this TileUpdateInputV1.
        The X position of the tile in the grid

        :return: The x of this TileUpdateInputV1.
        :rtype: int
        """
        return self._x

    @x.setter
    def x(self, x):
        """
        Sets the x of this TileUpdateInputV1.
        The X position of the tile in the grid

        :param x: The x of this TileUpdateInputV1.
        :type: int
        """

        self._x = x

    @property
    def y(self):
        """
        Gets the y of this TileUpdateInputV1.
        The Y position of the tile in the grid

        :return: The y of this TileUpdateInputV1.
        :rtype: int
        """
        return self._y

    @y.setter
    def y(self, y):
        """
        Sets the y of this TileUpdateInputV1.
        The Y position of the tile in the grid

        :param y: The y of this TileUpdateInputV1.
        :type: int
        """

        self._y = y

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TileUpdateInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ColumnRuleDescendantSearchInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'ancestor_property': 'str',
        'item_types': 'list[str]',
        'property_match_operators': 'list[str]',
        'property_names': 'list[str]',
        'property_values': 'list[str]'
    }

    attribute_map = {
        'ancestor_property': 'ancestorProperty',
        'item_types': 'itemTypes',
        'property_match_operators': 'propertyMatchOperators',
        'property_names': 'propertyNames',
        'property_values': 'propertyValues'
    }

    def __init__(self, ancestor_property=None, item_types=None, property_match_operators=None, property_names=None, property_values=None):
        """
        ColumnRuleDescendantSearchInputV1 - a model defined in Swagger
        """

        self._ancestor_property = None
        self._item_types = None
        self._property_match_operators = None
        self._property_names = None
        self._property_values = None

        if ancestor_property is not None:
          self.ancestor_property = ancestor_property
        if item_types is not None:
          self.item_types = item_types
        if property_match_operators is not None:
          self.property_match_operators = property_match_operators
        if property_names is not None:
          self.property_names = property_names
        if property_values is not None:
          self.property_values = property_values

    @property
    def ancestor_property(self):
        """
        Gets the ancestor_property of this ColumnRuleDescendantSearchInputV1.
        Accessor of the level in the event to search descendents from: ancestor[<level>] or parent[<level>].  If empty, the search will be performed from the source level of the event

        :return: The ancestor_property of this ColumnRuleDescendantSearchInputV1.
        :rtype: str
        """
        return self._ancestor_property

    @ancestor_property.setter
    def ancestor_property(self, ancestor_property):
        """
        Sets the ancestor_property of this ColumnRuleDescendantSearchInputV1.
        Accessor of the level in the event to search descendents from: ancestor[<level>] or parent[<level>].  If empty, the search will be performed from the source level of the event

        :param ancestor_property: The ancestor_property of this ColumnRuleDescendantSearchInputV1.
        :type: str
        """

        self._ancestor_property = ancestor_property

    @property
    def item_types(self):
        """
        Gets the item_types of this ColumnRuleDescendantSearchInputV1.
        The types of item to search for. If specified, each type must be a valid item type. If not              specified, the rule will search within all Signals, Conditions, and Scalars.

        :return: The item_types of this ColumnRuleDescendantSearchInputV1.
        :rtype: list[str]
        """
        return self._item_types

    @item_types.setter
    def item_types(self, item_types):
        """
        Sets the item_types of this ColumnRuleDescendantSearchInputV1.
        The types of item to search for. If specified, each type must be a valid item type. If not              specified, the rule will search within all Signals, Conditions, and Scalars.

        :param item_types: The item_types of this ColumnRuleDescendantSearchInputV1.
        :type: list[str]
        """

        self._item_types = item_types

    @property
    def property_match_operators(self):
        """
        Gets the property_match_operators of this ColumnRuleDescendantSearchInputV1.
        The operators to use for matching the property value. Available options are EQUALS, EQUALS_IGNORE_CASE, NOT_EQUALS, WITHIN, STRING_CONTAINS, REGEX_MATCHES, and NOT_REGEX_MATCHES.

        :return: The property_match_operators of this ColumnRuleDescendantSearchInputV1.
        :rtype: list[str]
        """
        return self._property_match_operators

    @property_match_operators.setter
    def property_match_operators(self, property_match_operators):
        """
        Sets the property_match_operators of this ColumnRuleDescendantSearchInputV1.
        The operators to use for matching the property value. Available options are EQUALS, EQUALS_IGNORE_CASE, NOT_EQUALS, WITHIN, STRING_CONTAINS, REGEX_MATCHES, and NOT_REGEX_MATCHES.

        :param property_match_operators: The property_match_operators of this ColumnRuleDescendantSearchInputV1.
        :type: list[str]
        """
        if property_match_operators is None:
            raise ValueError("Invalid value for `property_match_operators`, must not be `None`")

        self._property_match_operators = property_match_operators

    @property
    def property_names(self):
        """
        Gets the property_names of this ColumnRuleDescendantSearchInputV1.
        The property names to search.

        :return: The property_names of this ColumnRuleDescendantSearchInputV1.
        :rtype: list[str]
        """
        return self._property_names

    @property_names.setter
    def property_names(self, property_names):
        """
        Sets the property_names of this ColumnRuleDescendantSearchInputV1.
        The property names to search.

        :param property_names: The property_names of this ColumnRuleDescendantSearchInputV1.
        :type: list[str]
        """
        if property_names is None:
            raise ValueError("Invalid value for `property_names`, must not be `None`")

        self._property_names = property_names

    @property
    def property_values(self):
        """
        Gets the property_values of this ColumnRuleDescendantSearchInputV1.
        The property values to search for. 

        :return: The property_values of this ColumnRuleDescendantSearchInputV1.
        :rtype: list[str]
        """
        return self._property_values

    @property_values.setter
    def property_values(self, property_values):
        """
        Sets the property_values of this ColumnRuleDescendantSearchInputV1.
        The property values to search for. 

        :param property_values: The property_values of this ColumnRuleDescendantSearchInputV1.
        :type: list[str]
        """
        if property_values is None:
            raise ValueError("Invalid value for `property_values`, must not be `None`")

        self._property_values = property_values

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ColumnRuleDescendantSearchInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import sys
import os
import re

from deprecated import deprecated
# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient
from ..models import *

class HierarchiesApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def create_hierarchy(self, **kwargs):
        """
        Create a new hierarchy from an Item Table. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_hierarchy(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param HierarchyInputV1 body: (required)
        :return: HierarchyOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: HierarchyOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.create_hierarchy_with_http_info(**kwargs)
        else:
            (data) = self.create_hierarchy_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def create_hierarchy_with_http_info(self, **kwargs):
        """
        Create a new hierarchy from an Item Table. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_hierarchy_with_http_info(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param HierarchyInputV1 body: (required)
        :return: HierarchyOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: HierarchyOutputV1
        """

        all_params = ['body']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_hierarchy" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_hierarchy`")


        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/hierarchies', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'HierarchyOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def get_hierarchies(self, **kwargs):
        """
        Get a list of hierarchies. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_hierarchies(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int offset: The pagination offset, the index of the first item that will be returned in this page of results
        :param int limit: The pagination limit, the total number of hierarchies that will be returned in this page of results
        :param str table_definition_id: ID of the table definition that the hierarchy is created from
        :return: HierarchyOutputListV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: HierarchyOutputListV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_hierarchies_with_http_info(**kwargs)
        else:
            (data) = self.get_hierarchies_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def get_hierarchies_with_http_info(self, **kwargs):
        """
        Get a list of hierarchies. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_hierarchies_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int offset: The pagination offset, the index of the first item that will be returned in this page of results
        :param int limit: The pagination limit, the total number of hierarchies that will be returned in this page of results
        :param str table_definition_id: ID of the table definition that the hierarchy is created from
        :return: HierarchyOutputListV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: HierarchyOutputListV1
        """

        all_params = ['offset', 'limit', 'table_definition_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_hierarchies" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in params:
            query_params.append(('offset', params['offset']))
        if 'limit' in params:
            query_params.append(('limit', params['limit']))
        if 'table_definition_id' in params:
            query_params.append(('tableDefinitionId', params['table_definition_id']))

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/hierarchies', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'HierarchyOutputListV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def get_hierarchy(self, **kwargs):
        """
        Get a hierarchy by ID. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_hierarchy(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The ID of the hierarchy (required)
        :return: HierarchyOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: HierarchyOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_hierarchy_with_http_info(**kwargs)
        else:
            (data) = self.get_hierarchy_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def get_hierarchy_with_http_info(self, **kwargs):
        """
        Get a hierarchy by ID. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_hierarchy_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The ID of the hierarchy (required)
        :return: HierarchyOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: HierarchyOutputV1
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_hierarchy" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_hierarchy`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/hierarchies/{id}', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'HierarchyOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def get_hierarchy_nodes(self, **kwargs):
        """
        Get nodes in a hierarchy by ID. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_hierarchy_nodes(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The ID of the hierarchy (required)
        :param list[str] column_ids:
        :param list[str] column_values:
        :return: HierarchyNodeOutputListV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: HierarchyNodeOutputListV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_hierarchy_nodes_with_http_info(**kwargs)
        else:
            (data) = self.get_hierarchy_nodes_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def get_hierarchy_nodes_with_http_info(self, **kwargs):
        """
        Get nodes in a hierarchy by ID. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_hierarchy_nodes_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The ID of the hierarchy (required)
        :param list[str] column_ids:
        :param list[str] column_values:
        :return: HierarchyNodeOutputListV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: HierarchyNodeOutputListV1
        """

        all_params = ['id', 'column_ids', 'column_values']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_hierarchy_nodes" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_hierarchy_nodes`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []
        if 'column_ids' in params:
            query_params.append(('columnIds', params['column_ids']))
            collection_formats['columnIds'] = 'multi'
        if 'column_values' in params:
            query_params.append(('columnValues', params['column_values']))
            collection_formats['columnValues'] = 'multi'

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/hierarchies/{id}/nodes', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'HierarchyNodeOutputListV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def search_hierarchy_node(self, **kwargs):
        """
        Search for a hierarchy node with path nodes from a scaling table row reference. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.search_hierarchy_node(scaling_table_id=scaling_table_id_value, item_id=item_id_value, row_item_id=row_item_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str scaling_table_id: The ID of the Scaling Table being searched (required)
        :param str item_id: The ID of the item being searched for (required)
        :param str row_item_id: The ID the item that identifies the row of a Scaling Table (required)
        :param str row_datum_id: The datum ID that along with 'rowItemId' identifies the row of a Scaling Table
        :return: HierarchyNodeWithPathOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: HierarchyNodeWithPathOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.search_hierarchy_node_with_http_info(**kwargs)
        else:
            (data) = self.search_hierarchy_node_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def search_hierarchy_node_with_http_info(self, **kwargs):
        """
        Search for a hierarchy node with path nodes from a scaling table row reference. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.search_hierarchy_node_with_http_info(scaling_table_id=scaling_table_id_value, item_id=item_id_value, row_item_id=row_item_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str scaling_table_id: The ID of the Scaling Table being searched (required)
        :param str item_id: The ID of the item being searched for (required)
        :param str row_item_id: The ID the item that identifies the row of a Scaling Table (required)
        :param str row_datum_id: The datum ID that along with 'rowItemId' identifies the row of a Scaling Table
        :return: HierarchyNodeWithPathOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: HierarchyNodeWithPathOutputV1
        """

        all_params = ['scaling_table_id', 'item_id', 'row_item_id', 'row_datum_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method search_hierarchy_node" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'scaling_table_id' is set
        if ('scaling_table_id' not in params) or (params['scaling_table_id'] is None):
            raise ValueError("Missing the required parameter `scaling_table_id` when calling `search_hierarchy_node`")
        # verify the required parameter 'item_id' is set
        if ('item_id' not in params) or (params['item_id'] is None):
            raise ValueError("Missing the required parameter `item_id` when calling `search_hierarchy_node`")
        # verify the required parameter 'row_item_id' is set
        if ('row_item_id' not in params) or (params['row_item_id'] is None):
            raise ValueError("Missing the required parameter `row_item_id` when calling `search_hierarchy_node`")


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'scaling_table_id' in params:
            query_params.append(('scalingTableId', params['scaling_table_id']))
        if 'item_id' in params:
            query_params.append(('itemId', params['item_id']))
        if 'row_item_id' in params:
            query_params.append(('rowItemId', params['row_item_id']))
        if 'row_datum_id' in params:
            query_params.append(('rowDatumId', params['row_datum_id']))

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/hierarchies/node/search', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'HierarchyNodeWithPathOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def update_hierarchy(self, **kwargs):
        """
        Update a hierarchy. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_hierarchy(body=body_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param HierarchyInputV1 body: (required)
        :param str id: The Seeq ID for the hierarchy (required)
        :return: HierarchyOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: HierarchyOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.update_hierarchy_with_http_info(**kwargs)
        else:
            (data) = self.update_hierarchy_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def update_hierarchy_with_http_info(self, **kwargs):
        """
        Update a hierarchy. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_hierarchy_with_http_info(body=body_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param HierarchyInputV1 body: (required)
        :param str id: The Seeq ID for the hierarchy (required)
        :return: HierarchyOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: HierarchyOutputV1
        """

        all_params = ['body', 'id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_hierarchy" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_hierarchy`")
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `update_hierarchy`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/hierarchies/{id}', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'HierarchyOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def validate_hierarchy(self, **kwargs):
        """
        Validate a hierarchy by ID. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.validate_hierarchy(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The ID of the hierarchy (required)
        :return: HierarchyValidationOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: HierarchyValidationOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.validate_hierarchy_with_http_info(**kwargs)
        else:
            (data) = self.validate_hierarchy_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def validate_hierarchy_with_http_info(self, **kwargs):
        """
        Validate a hierarchy by ID. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.validate_hierarchy_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The ID of the hierarchy (required)
        :return: HierarchyValidationOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: HierarchyValidationOutputV1
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method validate_hierarchy" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `validate_hierarchy`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/hierarchies/{id}/validate', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'HierarchyValidationOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def validate_hierarchy_input(self, **kwargs):
        """
        Validate a hierarchy configuration. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.validate_hierarchy_input(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param HierarchyInputV1 body: (required)
        :return: HierarchyValidationOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: HierarchyValidationOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.validate_hierarchy_input_with_http_info(**kwargs)
        else:
            (data) = self.validate_hierarchy_input_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def validate_hierarchy_input_with_http_info(self, **kwargs):
        """
        Validate a hierarchy configuration. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.validate_hierarchy_input_with_http_info(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param HierarchyInputV1 body: (required)
        :return: HierarchyValidationOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: HierarchyValidationOutputV1
        """

        all_params = ['body']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method validate_hierarchy_input" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `validate_hierarchy_input`")


        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/hierarchies/validate', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'HierarchyValidationOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class CalculatedTableInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'description': 'str',
        'group_by': 'list[str]',
        'join': 'JoinInputV1',
        'name': 'str',
        'order_by': 'list[OrderByInputV1]',
        'select_expressions': 'list[CalculatedTableColumnInputV1]',
        'source': 'str'
    }

    attribute_map = {
        'description': 'description',
        'group_by': 'groupBy',
        'join': 'join',
        'name': 'name',
        'order_by': 'orderBy',
        'select_expressions': 'selectExpressions',
        'source': 'source'
    }

    def __init__(self, description=None, group_by=None, join=None, name=None, order_by=None, select_expressions=None, source=None):
        """
        CalculatedTableInputV1 - a model defined in Swagger
        """

        self._description = None
        self._group_by = None
        self._join = None
        self._name = None
        self._order_by = None
        self._select_expressions = None
        self._source = None

        if description is not None:
          self.description = description
        if group_by is not None:
          self.group_by = group_by
        if join is not None:
          self.join = join
        if name is not None:
          self.name = name
        if order_by is not None:
          self.order_by = order_by
        if select_expressions is not None:
          self.select_expressions = select_expressions
        if source is not None:
          self.source = source

    @property
    def description(self):
        """
        Gets the description of this CalculatedTableInputV1.
        Description for the calculated table

        :return: The description of this CalculatedTableInputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CalculatedTableInputV1.
        Description for the calculated table

        :param description: The description of this CalculatedTableInputV1.
        :type: str
        """

        self._description = description

    @property
    def group_by(self):
        """
        Gets the group_by of this CalculatedTableInputV1.
        Group by for the query

        :return: The group_by of this CalculatedTableInputV1.
        :rtype: list[str]
        """
        return self._group_by

    @group_by.setter
    def group_by(self, group_by):
        """
        Sets the group_by of this CalculatedTableInputV1.
        Group by for the query

        :param group_by: The group_by of this CalculatedTableInputV1.
        :type: list[str]
        """

        self._group_by = group_by

    @property
    def join(self):
        """
        Gets the join of this CalculatedTableInputV1.

        :return: The join of this CalculatedTableInputV1.
        :rtype: JoinInputV1
        """
        return self._join

    @join.setter
    def join(self, join):
        """
        Sets the join of this CalculatedTableInputV1.

        :param join: The join of this CalculatedTableInputV1.
        :type: JoinInputV1
        """

        self._join = join

    @property
    def name(self):
        """
        Gets the name of this CalculatedTableInputV1.
        The name of the Calculated Table

        :return: The name of this CalculatedTableInputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CalculatedTableInputV1.
        The name of the Calculated Table

        :param name: The name of this CalculatedTableInputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def order_by(self):
        """
        Gets the order_by of this CalculatedTableInputV1.
        Order by for the query

        :return: The order_by of this CalculatedTableInputV1.
        :rtype: list[OrderByInputV1]
        """
        return self._order_by

    @order_by.setter
    def order_by(self, order_by):
        """
        Sets the order_by of this CalculatedTableInputV1.
        Order by for the query

        :param order_by: The order_by of this CalculatedTableInputV1.
        :type: list[OrderByInputV1]
        """

        self._order_by = order_by

    @property
    def select_expressions(self):
        """
        Gets the select_expressions of this CalculatedTableInputV1.
        List of sql expressions corresponding to columns of a calculated table

        :return: The select_expressions of this CalculatedTableInputV1.
        :rtype: list[CalculatedTableColumnInputV1]
        """
        return self._select_expressions

    @select_expressions.setter
    def select_expressions(self, select_expressions):
        """
        Sets the select_expressions of this CalculatedTableInputV1.
        List of sql expressions corresponding to columns of a calculated table

        :param select_expressions: The select_expressions of this CalculatedTableInputV1.
        :type: list[CalculatedTableColumnInputV1]
        """
        if select_expressions is None:
            raise ValueError("Invalid value for `select_expressions`, must not be `None`")

        self._select_expressions = select_expressions

    @property
    def source(self):
        """
        Gets the source of this CalculatedTableInputV1.
        The source table that the calculated table is based on

        :return: The source of this CalculatedTableInputV1.
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """
        Sets the source of this CalculatedTableInputV1.
        The source table that the calculated table is based on

        :param source: The source of this CalculatedTableInputV1.
        :type: str
        """
        if source is None:
            raise ValueError("Invalid value for `source`, must not be `None`")

        self._source = source

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, CalculatedTableInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.1-v202602230103-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class TableDefinitionPreviewInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'bypass_model_controlled_restriction': 'bool',
        'column_definitions': 'ColumnDefinitionBulkEditInputListV1',
        'rows': 'list[RowId]'
    }

    attribute_map = {
        'bypass_model_controlled_restriction': 'bypassModelControlledRestriction',
        'column_definitions': 'columnDefinitions',
        'rows': 'rows'
    }

    def __init__(self, bypass_model_controlled_restriction=None, column_definitions=None, rows=None):
        """
        TableDefinitionPreviewInputV1 - a model defined in Swagger
        """

        self._bypass_model_controlled_restriction = None
        self._column_definitions = None
        self._rows = None

        if bypass_model_controlled_restriction is not None:
          self.bypass_model_controlled_restriction = bypass_model_controlled_restriction
        if column_definitions is not None:
          self.column_definitions = column_definitions
        if rows is not None:
          self.rows = rows

    @property
    def bypass_model_controlled_restriction(self):
        """
        Gets the bypass_model_controlled_restriction of this TableDefinitionPreviewInputV1.
        If true, allows previewing modifications to model-controlled columns. Model-controlled columns are columns created by applying a model to a table. By default, these columns cannot be modified directly to preserve model integrity. Set this to true when previewing changes to model features. Since preview is a transient operation that doesn't persist changes, bypassing this restriction is safe.

        :return: The bypass_model_controlled_restriction of this TableDefinitionPreviewInputV1.
        :rtype: bool
        """
        return self._bypass_model_controlled_restriction

    @bypass_model_controlled_restriction.setter
    def bypass_model_controlled_restriction(self, bypass_model_controlled_restriction):
        """
        Sets the bypass_model_controlled_restriction of this TableDefinitionPreviewInputV1.
        If true, allows previewing modifications to model-controlled columns. Model-controlled columns are columns created by applying a model to a table. By default, these columns cannot be modified directly to preserve model integrity. Set this to true when previewing changes to model features. Since preview is a transient operation that doesn't persist changes, bypassing this restriction is safe.

        :param bypass_model_controlled_restriction: The bypass_model_controlled_restriction of this TableDefinitionPreviewInputV1.
        :type: bool
        """

        self._bypass_model_controlled_restriction = bypass_model_controlled_restriction

    @property
    def column_definitions(self):
        """
        Gets the column_definitions of this TableDefinitionPreviewInputV1.

        :return: The column_definitions of this TableDefinitionPreviewInputV1.
        :rtype: ColumnDefinitionBulkEditInputListV1
        """
        return self._column_definitions

    @column_definitions.setter
    def column_definitions(self, column_definitions):
        """
        Sets the column_definitions of this TableDefinitionPreviewInputV1.

        :param column_definitions: The column_definitions of this TableDefinitionPreviewInputV1.
        :type: ColumnDefinitionBulkEditInputListV1
        """
        if column_definitions is None:
            raise ValueError("Invalid value for `column_definitions`, must not be `None`")

        self._column_definitions = column_definitions

    @property
    def rows(self):
        """
        Gets the rows of this TableDefinitionPreviewInputV1.
        The datumId/itemId combinations of the desired rows to preview in the table. If not provided, the table will be populated with the first 50 rows from the table.

        :return: The rows of this TableDefinitionPreviewInputV1.
        :rtype: list[RowId]
        """
        return self._rows

    @rows.setter
    def rows(self, rows):
        """
        Sets the rows of this TableDefinitionPreviewInputV1.
        The datumId/itemId combinations of the desired rows to preview in the table. If not provided, the table will be populated with the first 50 rows from the table.

        :param rows: The rows of this TableDefinitionPreviewInputV1.
        :type: list[RowId]
        """

        self._rows = rows

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TableDefinitionPreviewInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
